<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Repeater;
use \Elementor\Utils;
use \Elementor\Group_Control_Border;
/**
 *
 * Banner Widget .
 *
 */
class Appku_Banner_V2 extends Widget_Base {

	public function get_name() {
		return 'appkubannerv2';
	}

	public function get_title() {
		return __( 'Banner v2', 'appku' );
	}

	public function get_icon() {
		return 'eicon-code';
    }

	public function get_categories() {
		return [ 'appku_header_elements' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'Banner_section',
			[
				'label' 	=> __( 'Banner', 'appku' ),
				'tab' 		=> Controls_Manager::TAB_CONTENT,
			]
        );

		$this->add_control(
			'banner_style',
			[
				'label' 		=> __( 'Banner Style', 'appku' ),
				'type' 			=> Controls_Manager::SELECT,
				'default' 		=> '1',
				'options' 		=> [
					'1'  		=> __( 'Style One', 'appku' ),
					'2' 		=> __( 'Style Two', 'appku' ),
					'3' 		=> __( 'Style Three', 'appku' ),
				],
			]
		);

		$this->add_control(
			'banner_image',
			[
				'label' 		=> __( 'Banner Image', 'appku' ),
				'type' 			=> Controls_Manager::MEDIA,
				'default' 		=> [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);
		$this->add_control(
			'banner_image2',
			[
				'label' 		=> __( 'Banner Image 2', 'appku' ),
				'type' 			=> Controls_Manager::MEDIA,
				'default' 		=> [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);
		$this->add_control(
			'banner_image3',
			[
				'label' 		=> __( 'Banner Image 3', 'appku' ),
				'type' 			=> Controls_Manager::MEDIA,
				'default' 		=> [
					'url' => Utils::get_placeholder_image_src(),
				],
				'condition'		=> [ 'banner_style' => [ '1', '2' ] ],
			]
		);

		$this->add_control(
			'title',
			[
				'label' 	=> __( 'Banner Title', 'appku' ),
                'type' 		=> Controls_Manager::TEXTAREA,
                'rows' 		=> 2,
                'default'  	=> __( 'We re building software<strong>to manage business</strong>', 'appku' )
			]
        );
        $this->add_control(
			'curve_text',
			[
				'label' 	=> __( 'Curve Text', 'appku' ),
                'type' 		=> Controls_Manager::TEXTAREA,
                'rows' 		=> 2,
                'default'  	=> __( 'We re building software<strong>to manage business</strong>', 'appku' ),
                'condition'		=> [ 'banner_style' => [ '2' ] ],
			]
        );
        $this->add_control(
			'subtitle',
			[
				'label' 	=> __( 'Banner Subtitle', 'appku' ),
                'type' 		=> Controls_Manager::TEXTAREA,
                'rows' 		=> 2,
                'default'  	=> __( 'We re building software<strong>to manage business</strong>', 'appku' ),
                'condition'		=> [ 'banner_style' => [ '1' ] ],
			]
        );
        $this->add_control(
			'desc',
			[
				'label' 	=> __( 'Banner Description', 'appku' ),
                'type' 		=> Controls_Manager::TEXTAREA,
                'rows' 		=> 2,
                'default'  	=> __( 'Lasted hunted enough an up seeing in lively letter. Had judgment out opinions property the supplied.', 'appku' ),
                'condition'		=> [ 'banner_style' => [ '1', '2' ] ],
			]
        );
        $this->add_control(
			'custom_html',
			[
				'label' => esc_html__( 'Chart Info', 'appku' ),
				'type' => Controls_Manager::CODE,
				'language' => 'html',
				'rows' => 10,
				'condition'		=> [ 'banner_style' => [ '1' ] ],
			]
		);
        
        $this->add_control(
			'button_text',
			[
				'label' 	=> __( 'Button Text', 'appku' ),
                'type' 		=> Controls_Manager::TEXT,
                'default'  	=> __( 'Button Text', 'appku' ),
                'condition'		=> [ 'banner_style' => [ '1' ] ],
                // 'condition'		=> [ 'banner_style' => [ '1','4','5' ] ],
			]
        );

        $this->add_control(
			'button_link',
			[
				'label' 		=> __( 'Link', 'appku' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder' 	=> __( 'https://your-link.com', 'appku' ),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> false,
				],
				'condition'		=> [ 'banner_style' => [ '1' ] ],
				// 'condition'		=> [ 'banner_style' => [ '1','4' ,'5'] ],
			]
		);
		$this->add_control(
			'video_btn_label',
			[
				'label' 	=> __( 'Video Button Label', 'appku' ),
                'type' 		=> Controls_Manager::TEXT,
                'default'  	=> __( 'Watch Promo', 'appku' ),
                'condition'		=> [ 'banner_style' => [ '3' ] ],
			]
        );
		$this->add_control(
			'video_url',
			[
				'label' 		=> __( 'Video Url', 'appku' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder' 	=> __( 'https://your-link.com', 'appku' ),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> false,
				],
				'condition'		=> [ 'banner_style' => [ '3'] ],
			]
		);

		// $this->add_control(
		// 	'button_text2',
		// 	[
		// 		'label' 	=> __( '2nd Button Text', 'appku' ),
  //               'type' 		=> Controls_Manager::TEXT,
  //               'default'  	=> __( 'Button Text', 'appku' ),
  //               'condition'		=> [ 'banner_style' => [ '5' ] ],
		// 	]
  //       );

  //       $this->add_control(
		// 	'button_link2',
		// 	[
		// 		'label' 		=> __( '2nd Button Link', 'appku' ),
		// 		'type' 			=> Controls_Manager::URL,
		// 		'placeholder' 	=> __( 'https://your-link.com', 'appku' ),
		// 		'show_external' => true,
		// 		'default' 		=> [
		// 			'url' 			=> '#',
		// 			'is_external' 	=> false,
		// 			'nofollow' 		=> false,
		// 		],
		// 		'condition'		=> [ 'banner_style' => [ '5'] ],
		// 	]
		// );
		// $this->add_control(
		// 	'video_btn_label',
		// 	[
		// 		'label' 	=> __( 'Video Button Label', 'appku' ),
  //               'type' 		=> Controls_Manager::TEXT,
  //               'default'  	=> __( 'Watch Promo', 'appku' ),
  //               'condition'		=> [ 'banner_style' => [ '2', '6' ] ],
		// 	]
  //       );
		// $this->add_control(
		// 	'video_url',
		// 	[
		// 		'label' 		=> __( 'Video Url', 'appku' ),
		// 		'type' 			=> Controls_Manager::URL,
		// 		'placeholder' 	=> __( 'https://your-link.com', 'appku' ),
		// 		'show_external' => true,
		// 		'default' 		=> [
		// 			'url' 			=> '#',
		// 			'is_external' 	=> false,
		// 			'nofollow' 		=> false,
		// 		],
		// 		'condition'		=> [ 'banner_style' => [ '2', '6'] ],
		// 	]
		// );

        $this->end_controls_section();

        //---------------------------------------Title Style---------------------------------------//

		$this->start_controls_section(
			'title_style',
			[
				'label' 	=> __( 'Title Style', 'appku' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'title_color',
			[
				'label' 		=> __( 'Title Color', 'appku' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} h2' => 'color: {{VALUE}}',
                ],
			]
        );
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'title_typography',
				'label' 	=> __( 'Title Typography', 'appku' ),
                'selector' 	=> '{{WRAPPER}} h2',
			]
        );
        $this->add_responsive_control(
			'title_margin',
			[
				'label' 		=> __( 'Title Margin', 'appku' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} h2' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
			]
        );

        $this->add_responsive_control(
			'title_padding',
			[
				'label' 		=> __( 'Title Padding', 'appku' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} h2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
			]
		);
		$this->end_controls_section();

		//---------------------------------------subTitle Style---------------------------------------//

		$this->start_controls_section(
			'subtitle_style',
			[
				'label' 	=> __( 'Subtitle Style', 'appku' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
				'condition'		=> [ 'banner_style' => [ '4' ] ],
			]
		);
		$this->add_control(
			'subtitle_color',
			[
				'label' 		=> __( 'Subtitle Color', 'appku' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} h4' => 'color: {{VALUE}}',
                ],
			]
        );
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'subtitle_typography',
				'label' 	=> __( 'Subtitle Typography', 'appku' ),
                'selector' 	=> '{{WRAPPER}} h4',
			]
        );
        $this->add_responsive_control(
			'subtitle_margin',
			[
				'label' 		=> __( 'Subtitle Margin', 'appku' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} h4' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
			]
        );

        $this->add_responsive_control(
			'subtitle_padding',
			[
				'label' 		=> __( 'Subtitle Padding', 'appku' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} h4' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
			]
		);
		$this->end_controls_section();

		//---------------------------------------Descriptions Style---------------------------------------//

		$this->start_controls_section(
			'desc_style',
			[
				'label' 	=> __( 'Descriptions Style', 'appku' ),
				'tab' 		=> Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'desc_color',
			[
				'label' 		=> __( 'Descriptions Color', 'appku' ),
				'type' 			=> Controls_Manager::COLOR,
				'selectors' 	=> [
					'{{WRAPPER}} p' => 'color: {{VALUE}}',
                ],
			]
        );
        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' 		=> 'desc_typography',
				'label' 	=> __( 'Descriptions Typography', 'appku' ),
                'selector' 	=> '{{WRAPPER}} p',
			]
        );
        $this->add_responsive_control(
			'desc_margin',
			[
				'label' 		=> __( 'Descriptions Margin', 'appku' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .banner_btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
			]
        );

        $this->add_responsive_control(
			'desc_padding',
			[
				'label' 		=> __( 'Descriptions Padding', 'appku' ),
				'type' 			=> Controls_Manager::DIMENSIONS,
				'size_units' 	=> [ 'px', '%', 'em' ],
				'selectors' 	=> [
					'{{WRAPPER}} p' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .banner_btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
			]
		);
		$this->end_controls_section();


    }

	protected function render() {

        $settings = $this->get_settings_for_display();

		if( $settings['banner_style'] == '1' ){
			if( ! empty( $settings['banner_image']['url'] ) ){
				echo '<div class="business-banner overflow-hidden bg-cover" style="background-image: url('.esc_url( $settings['banner_image']['url'] ).');">';
			}
		        echo '<div class="container">';
		            echo '<div class="double-items">';
		                echo '<div class="row align-center">';

		                    echo '<div class="col-lg-5 info">';
		                        if(!empty($settings['title'])){
			                        echo '<h4>'.wp_kses_post($settings['title']).'</h4>';
			                    }
			                    if(!empty($settings['subtitle'])){
			                        echo '<h2>'.wp_kses_post($settings['subtitle']).'</h2>';
			                    }
			                    if(!empty($settings['desc'])){
			                        echo '<p>'.wp_kses_post($settings['desc']).'</p>';
			                    }
			                    if( ! empty( $settings['button_text'] ) ) {
			                    	if( ! empty( $settings['button_link']['url'] ) ) {
							            $this->add_render_attribute( 'button', 'href', esc_url( $settings['button_link']['url'] ) );
							        }
				            		if( ! empty( $settings['button_link']['nofollow'] ) ) {
							            $this->add_render_attribute( 'button', 'rel', 'nofollow' );
							        }
							        if( ! empty( $settings['button_link']['is_external'] ) ) {
							            $this->add_render_attribute( 'button', 'target', '_blank' );
							        }
							        $this->add_render_attribute( 'button', 'class', 'btn-animation mt-15' );

			                        echo '<a '.$this->get_render_attribute_string('button').'><i class="fas fa-arrow-right"></i> <span>'.esc_html( $settings['button_text'] ).' </span></a>';
			                    }
		                    echo '</div>';

		                     echo '<div class="col-lg-6 offset-lg-1 business-banner-thumb">';
		                     	if( ! empty( $settings['banner_image2']['url'] ) ){
	                        		echo appku_img_tag( array(
										'url'	=> esc_url( $settings['banner_image2']['url'] ),
										'class' => 'wow fadeInUp',
									) );
	                        	}
	                        	if( ! empty( $settings['banner_image3']['url'] ) ){
	                        		echo appku_img_tag( array(
										'url'	=> esc_url( $settings['banner_image3']['url'] ),
										'class' => 'wow fadeInRight',
										'data-wow-delay' => '900ms'
									) );
	                        	}
		                        echo '<div class="revenew wow fadeInDown" data-wow-delay="500ms">';
		                            
		                        	echo $settings['custom_html'];

		                        echo '</div>';
		                    echo '</div>';
		                    
		                echo '</div>';
		            echo '</div>';
		        echo '</div>';
		    echo '</div>';
		}elseif( $settings['banner_style'] == '2' ){
			if( ! empty( $settings['banner_image']['url'] ) ){
				echo '<div class="banner-style-creative text-light bg-cover" style="background-image: url('.esc_url( $settings['banner_image']['url'] ).');">';
			}
		        echo '<div class="container">';
		            echo '<div class="row align-center">';
		                echo '<div class="col-lg-12 text-center banner-creative-item">';
		                    if(!empty($settings['title'])){
		                        echo '<h2>'.wp_kses_post($settings['title']).'</h2>';
		                    }
		                    echo '<div class="bottom">';
		                        if( ! empty( $settings['banner_image2']['url'] ) ){
	                        		echo appku_img_tag( array(
										'url'	=> esc_url( $settings['banner_image2']['url'] ),
									) );
	                        	}
		                        echo '<div class="content">';
		                            echo '<div class="curve-text">';
		                                echo '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 150 150" version="1.1"><path id="textPath" d="M 0,75 a 75,75 0 1,1 0,1 z"></path><text><textPath href="#textPath">'.esc_html($settings['curve_text']).'</textPath></text></svg>';
		                                if( ! empty( $settings['banner_image3']['url'] ) ){
			                        		echo appku_img_tag( array(
												'url'	=> esc_url( $settings['banner_image3']['url'] ),
											) );
			                        	}
		                            echo '</div>';
		                            if(!empty($settings['desc'])){
				                        echo '<p>'.wp_kses_post($settings['desc']).'</p>';
				                    }
		                        echo '</div>';
		                    echo '</div>';
		                echo '</div>';
		            echo '</div>';
		        echo '</div>';
		    echo '</div>';
		}elseif( $settings['banner_style'] == '3' ){

			if( ! empty( $settings['banner_image']['url'] ) ){
				echo '<div class="it-banner text-light bg-cover" style="background-image: url('.esc_url( $settings['banner_image']['url'] ).');">';
			}
		        echo '<div class="container">';
		            echo '<div class="double-items">';
		                echo '<div class="row align-center">';

		                    echo '<div class="col-lg-6 info">';
		                        if(!empty($settings['title'])){
			                        echo '<h2>'.wp_kses_post($settings['title']).'</h2>';
			                    }
		                        echo '<a href="'.esc_url( $settings['video_url']['url'] ).'" class="popup-youtube video-btn"><i class="fas fa-play"></i>'.esc_html( $settings['video_btn_label'] ).'</a>';
		                    echo '</div>';

		                    if( ! empty( $settings['banner_image2']['url'] ) ){
		                    	echo '<div class="col-lg-6 it-banner-thumb">';
	                        		echo appku_img_tag( array(
										'url'	=> esc_url( $settings['banner_image2']['url'] ),
									) );
								echo '</div>';
                        	}		                    
		                echo '</div>';
		            echo '</div>';
		        echo '</div>';
		    echo '</div>';
		}
	}
}