<?php
use \Elementor\Widget_Base;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Typography;
use \Elementor\Utils;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Repeater;
use \Elementor\Group_Control_Box_Shadow;
use \Elementor\Group_Control_Border;
/**
 *
 * Portfolio Banner Widget .
 *
 */
class Appku_Portfolio_Banner extends Widget_Base {

	public function get_name() {
		return 'appkuportfoliobanner';
	}

	public function get_title() {
		return __( 'Portfolio Banner', 'appku' );
	}


	public function get_icon() {
		return 'eicon-code';
    }


	public function get_categories() {
		return [ 'appku_portfolio' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'p_banner_section',
			[
				'label' 	=> __( 'Banner For Portfolio', 'appku' ),
				'tab' 		=> Controls_Manager::TAB_CONTENT,
			]
        );
        $this->add_control(
			'shadow_text',
			[
				'label'     => __( 'Shadow Text', 'appku' ),
                'type'      => Controls_Manager::TEXTAREA,
                'rows' 		=> 2,
                'default'  	=> __( 'Welcome', 'appku' )
			]
        );
        $this->add_control(
			'hello_text',
			[
				'label'     => __( 'Hello Text', 'appku' ),
                'type'      => Controls_Manager::TEXTAREA,
                'rows' 		=> 2,
                'default'  	=> __( 'Hi', 'appku' ),
			]
        );
        $this->add_control(
			'name',
			[
				'label'     => __( 'Name', 'appku' ),
                'type'      => Controls_Manager::TEXTAREA,
                'rows' 		=> 2,
                'default'  	=> __( " I'm <span>Easton</span>", 'appku' ),
			]
        );
        $this->add_control(
			'image',
			[
				'label' 		=> __( 'Banner Image', 'appku' ),
				'type' 			=> Controls_Manager::MEDIA,
				'default' 		=> [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);
		$repeater = new Repeater();

		$repeater->add_control(
			'skill',
			[
				'label'     => __( 'Skill', 'appku' ),
                'type'      => Controls_Manager::TEXTAREA,
                'rows' 		=> 2,
                'default'  	=> __( "WordPress", 'appku' ),
			]
        );
		$this->add_control(

			'skills',
			[
				'label' 		=> __( 'Add Your Skill', 'appku' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'default' 		=> [
					[
						'skill' => __( 'WordPress','appku' ),
					],
				],
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'social_icon',
			[
				'label' 	=> __( 'Social Icon', 'appku' ),
				'type' 		=> Controls_Manager::ICONS,
				'default' 	=> [
					'value' 	=> 'fab fa-facebook-f',
					'library' 	=> 'solid',
				],
			]
		);

		$repeater->add_control(
			'icon_link',
			[
				'label' 		=> __( 'Link', 'appku' ),
				'type' 			=> Controls_Manager::URL,
				'placeholder' 	=> __( 'https://your-link.com', 'appku' ),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> true,
					'nofollow' 		=> true,
				],
			]
		);

		$this->add_control(

			'social_icon_list',
			[
				'label' 		=> __( 'Social Icon', 'appku' ),
				'type' 			=> Controls_Manager::REPEATER,
				'fields' 		=> $repeater->get_controls(),
				'default' 		=> [
					[
						'social_icon' => __( 'Add Social Icon','appku' ),
					],
				],
			]
		);


        $this->end_controls_section();
	}

	protected function render() {

        $settings = $this->get_settings_for_display();


        // $this->add_render_attribute('wrapper','class',esc_attr( $settings['image_wrapper_class'] ));

    	echo '<div class="banner-area auto-height bg-fixed banner-style-six">';
	        echo '<div class="container">';
	            echo '<div class="double-items">';
	                echo '<div class="row align-center">';

	                    echo '<div class="col-lg-6 info">';
	                    	if(!empty($settings['shadow_text'])){
		                        echo '<h1 class="text-invisible">'.esc_html($settings['shadow_text']).'</h1>';
		                    }
	                        echo '<h2>'.esc_html($settings['hello_text']).' <img src="'.APPKU_PLUGDIRURI . 'assets/img/4.png" alt="Icon"> '.wp_kses_post($settings['name']).'</h2>';
	                        echo '<h3 class="title">';
	                            echo '<span class="header-caption" id="page-top">';
	                                echo '<!-- type headline start-->';
	                                echo '<span class="cd-headline clip is-full-width">';
	                                    echo '<!-- ROTATING TEXT -->';
	                                    echo '<span class="cd-words-wrapper">';
	                                    	$i = 0;
	                                    	foreach( $settings['skills'] as $data ){
	                                    		$i++;
	                                    		$class = ($i == 1 ) ? 'is-visible' : 'is-hidden';
		                                        echo '<b class="'.esc_attr($class).'">'.esc_html($data['skill']).'</b>';
		                                    }
	                                    echo '</span>';
	                                echo '</span>';
	                                echo '<!-- type headline end -->';
	                            echo '</span>';
	                        echo '</h3>';
	                    echo '</div>';
	                     echo '<div class="col-lg-6 thumb" data-wow-delay="900ms">';
	                     	if(!empty($settings['image']['url'])){
	                        	echo '<img class=" wow fadeInDown" src="'.esc_url($settings['image']['url']).'" alt="Thumb">';
	                    	}
	                        echo '<div class="shape-center">';
	                            echo '<img src="'.APPKU_PLUGDIRURI . 'assets/img/2.png" alt="Thumb">';
	                        echo '</div>';
	                    echo '</div>';
	                    
	                echo '</div>';
	                echo '<div class="personal-social">';
	                    echo '<ul>';
	                    	if( ! empty( $settings['social_icon_list'] ) ){

	                    		foreach( $settings['social_icon_list'] as $social_icon ){
		                          	$social_target    = $social_icon['icon_link']['is_external'] ? ' target="_blank"' : '';
		                          	$social_nofollow  = $social_icon['icon_link']['nofollow'] ? ' rel="nofollow"' : '';

		                            echo '<li><a '.wp_kses_post( $social_target.$social_nofollow ).' href="'.esc_url( $social_icon['icon_link']['url'] ).'">';

		                            \Elementor\Icons_Manager::render_icon( $social_icon['social_icon'], [ 'aria-hidden' => 'true' ] );

		                          	echo '</a></li>';
		                      	}
	                    	}
	                    echo '</ul>';
	                echo '</div>';
	            echo '</div>';
	        echo '</div>';
	    echo '</div>';
	}

}